##  4. Types of cookies and local storage objects used in SAP LeanIX Workspaces
  * ESSENTIAL: “essential” are those technical cookies/local storage objects that are necessary to manage your flow within the website or to keep you logged in. If you block them, it is possible that certain parts of the website might not work properly.
  * FUNCTIONALITY: “functionality” cookies/local storage objects are cookies not essential for the functioning of the overall application, but are required by certain functionality.If you block them, it is possible that certain parts of the website might not work properly.
  * ANALYTICS: “analytics” cookies/local storage objects are used to collect information to help understand how the website/services are being used by Users
  * MARKETING: “marketing” or “advertising” cookies/local storage objects are used to deliver adverts more relevant to users and their interests.
